@@ -18,17 +18,6 @@ my $defs = [
         },
         message => sub { "The value `$_[0]' is not a DateTime object." },
     },
-    {
-        name => 'Hook',
-        test => sub {
-            return
-                 $_[0]
-              && blessed( $_[0] )
-              && ref( $_[0] ) eq 'Interchange6::Hook';
-        },
-        message =>
-          sub { "The value `$_[0]' is not a Interchange6::Hook object." },
-    },
     {
         name    => 'NotEmpty',
         test    => sub { $_[0] =~ /\S/ },
@@ -47,6 +36,12 @@ my $defs = [
         test => sub { defined($_[0]) && $_[0] =~ /^(\d+)(\.\d+)?$/ && $_[0] > 0 },
         message => sub { "is not a positive numeric." }
     },
+    {
+        name => 'Zero',
+        test =>
+          sub { defined( $_[0] ) && $_[0] =~ /^(\d+)(\.\d+)?$/ && $_[0] == 0 },
+        message => sub { "is not zero." }
+    },
 ];
 
 for my $type (
